@@ -1,4 +1,4 @@
-'''
+r'''
 # Hyperledger Fabric on Amazon Managed Blockchain
 
 [![license](https://img.shields.io/github/license/cdklabs/cdk-hyperledger-fabric-network?color=green)](https://opensource.org/licenses/MIT)
@@ -143,6 +143,9 @@ See [CONTRIBUTING](CONTRIBUTING.md#security-issue-notifications) for more inform
 
 This project is licensed under the MIT-0 License. See the [LICENSE](LICENSE) file for details.
 '''
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
